@@ -21,7 +21,7 @@
 #include <system.h>
 #include <unistd.h>
 #ifdef __linux__
-# include <sys/prctl.h>
+#include <sys/prctl.h>
 #endif
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -47,8 +47,9 @@ void pr_set_undumpable(const char *mod)
 #ifdef __linux__
 	if (prctl(PR_SET_DUMPABLE, 0) == -1) {
 		int e = errno;
-		oc_syslog(LOG_ERR, "%s: prctl(PR_SET_DUMPABLE) failed %s",
-			mod, strerror(e));
+
+		oc_syslog(LOG_ERR, "%s: prctl(PR_SET_DUMPABLE) failed %s", mod,
+			  strerror(e));
 	}
 #endif
 }
@@ -60,17 +61,18 @@ SIGHANDLER_T ocsignal(int signum, SIGHANDLER_T handler)
 	memset(&new_action, 0, sizeof(new_action));
 
 	new_action.sa_handler = handler;
-	sigemptyset (&new_action.sa_mask);
+	sigemptyset(&new_action.sa_mask);
 	new_action.sa_flags = 0;
 
-	sigaction (signum, &new_action, &old_action);
+	sigaction(signum, &new_action, &old_action);
 	return old_action.sa_handler;
 }
 
 /* Checks whether the peer in a socket has the expected @uid and @gid.
  * Returns zero on success.
  */
-int check_upeer_id(const char *mod, int debug, int cfd, uid_t uid, uid_t gid, uid_t *ruid, pid_t *pid)
+int check_upeer_id(const char *mod, int debug, int cfd, uid_t uid, uid_t gid,
+		   uid_t *ruid, pid_t *pid)
 {
 	int e, ret;
 #if defined(SO_PEERCRED) && defined(HAVE_STRUCT_UCRED)
@@ -85,15 +87,15 @@ int check_upeer_id(const char *mod, int debug, int cfd, uid_t uid, uid_t gid, ui
 	ret = getsockopt(cfd, SOL_SOCKET, SO_PEERCRED, &cr, &cr_len);
 	if (ret == -1) {
 		e = errno;
-		oc_syslog(LOG_ERR, "%s: getsockopt SO_PEERCRED error: %s",
-			mod, strerror(e));
+		oc_syslog(LOG_ERR, "%s: getsockopt SO_PEERCRED error: %s", mod,
+			  strerror(e));
 		return -1;
 	}
 
 	if (debug >= OCLOG_DEBUG)
 		oc_syslog(LOG_DEBUG,
-		       "%s: received request from pid %u and uid %u",
-		       mod, (unsigned)cr.pid, (unsigned)cr.uid);
+			  "%s: received request from pid %u and uid %u", mod,
+			  (unsigned int)cr.pid, (unsigned int)cr.uid);
 
 	if (ruid)
 		*ruid = cr.uid;
@@ -102,10 +104,11 @@ int check_upeer_id(const char *mod, int debug, int cfd, uid_t uid, uid_t gid, ui
 		*pid = cr.pid;
 
 	if (cr.uid != 0 && (cr.uid != uid || cr.gid != gid)) {
-		oc_syslog(LOG_ERR,
-		       "%s: received unauthorized request from pid %u and uid %u",
-		       mod, (unsigned)cr.pid, (unsigned)cr.uid);
-			return -1;
+		oc_syslog(
+			LOG_ERR,
+			"%s: received unauthorized request from pid %u and uid %u",
+			mod, (unsigned int)cr.pid, (unsigned int)cr.uid);
+		return -1;
 	}
 #elif defined(HAVE_GETPEEREID)
 	uid_t euid;
@@ -115,8 +118,8 @@ int check_upeer_id(const char *mod, int debug, int cfd, uid_t uid, uid_t gid, ui
 
 	if (ret == -1) {
 		e = errno;
-		oc_syslog(LOG_DEBUG, "%s: getpeereid error: %s",
-			mod, strerror(e));
+		oc_syslog(LOG_DEBUG, "%s: getpeereid error: %s", mod,
+			  strerror(e));
 		return -1;
 	}
 
@@ -128,14 +131,15 @@ int check_upeer_id(const char *mod, int debug, int cfd, uid_t uid, uid_t gid, ui
 
 	if (debug >= OCLOG_DEBUG)
 		oc_syslog(LOG_DEBUG,
-		       "%s: received request from a processes with uid %u",
-		       mod, (unsigned)euid);
+			  "%s: received request from a processes with uid %u",
+			  mod, (unsigned int)euid);
 
 	if (euid != 0 && (euid != uid || egid != gid)) {
-		oc_syslog(LOG_ERR,
-		       "%s: received unauthorized request from a process with uid %u",
-			mod, (unsigned)euid);
-			return -1;
+		oc_syslog(
+			LOG_ERR,
+			"%s: received unauthorized request from a process with uid %u",
+			mod, (unsigned int)euid);
+		return -1;
 	}
 #else
 #error "Unsupported UNIX variant"
