@@ -50,7 +50,7 @@
 #include "log.h"
 
 #ifndef UNDER_TEST
-static void tls_reload_ocsp(main_server_st* s, struct vhost_cfg_st *vhost);
+static void tls_reload_ocsp(main_server_st *s, struct vhost_cfg_st *vhost);
 #endif /* UNDER_TEST */
 
 void cstp_cork(worker_st *ws)
@@ -60,12 +60,15 @@ void cstp_cork(worker_st *ws)
 	} else {
 		int state = 1, ret = 0;
 #if defined(__linux__)
-		ret = setsockopt(ws->conn_fd, IPPROTO_TCP, TCP_CORK, &state, sizeof(state));
+		ret = setsockopt(ws->conn_fd, IPPROTO_TCP, TCP_CORK, &state,
+				 sizeof(state));
 #elif defined(TCP_NOPUSH)
-		ret = setsockopt(ws->conn_fd, IPPROTO_TCP, TCP_NOPUSH, &state, sizeof(state));
+		ret = setsockopt(ws->conn_fd, IPPROTO_TCP, TCP_NOPUSH, &state,
+				 sizeof(state));
 #endif
 		if (ret == -1) {
-			oclog(ws, LOG_ERR, "setsockopt(IPPROTO_TCP(TCP_CORK) failed");
+			oclog(ws, LOG_ERR,
+			      "setsockopt(IPPROTO_TCP(TCP_CORK) failed");
 		}
 	}
 }
@@ -77,30 +80,32 @@ int cstp_uncork(worker_st *ws)
 	} else {
 		int state = 0, ret = 0;
 #if defined(__linux__)
-		ret = setsockopt(ws->conn_fd, IPPROTO_TCP, TCP_CORK, &state, sizeof(state));
+		ret = setsockopt(ws->conn_fd, IPPROTO_TCP, TCP_CORK, &state,
+				 sizeof(state));
 #elif defined(TCP_NOPUSH)
-		ret = setsockopt(ws->conn_fd, IPPROTO_TCP, TCP_NOPUSH, &state, sizeof(state));
+		ret = setsockopt(ws->conn_fd, IPPROTO_TCP, TCP_NOPUSH, &state,
+				 sizeof(state));
 #endif
 		if (ret == -1) {
-			oclog(ws, LOG_ERR, "setsockopt(IPPROTO_TCP(TCP_UNCORK) failed");
+			oclog(ws, LOG_ERR,
+			      "setsockopt(IPPROTO_TCP(TCP_UNCORK) failed");
 		}
 		return 0;
 	}
 }
 
-
-ssize_t cstp_send(worker_st *ws, const void *data,
-			size_t data_size)
+ssize_t cstp_send(worker_st *ws, const void *data, size_t data_size)
 {
 	int ret;
 	int left = data_size;
-	const uint8_t* p = data;
+	const uint8_t *p = data;
 
 	if (ws->session != NULL) {
 		while (left > 0) {
 			ret = gnutls_record_send(ws->session, p, data_size);
 			if (ret < 0) {
-				if (ret != GNUTLS_E_AGAIN && ret != GNUTLS_E_INTERRUPTED) {
+				if (ret != GNUTLS_E_AGAIN &&
+				    ret != GNUTLS_E_INTERRUPTED) {
 					return ret;
 				} else {
 					/* do not cause mayhem */
@@ -131,9 +136,9 @@ ssize_t cstp_send_file(worker_st *ws, const char *file)
 	if (fd == -1)
 		return GNUTLS_E_FILE_ERROR;
 
-	while (	(len = read( fd, buf, sizeof(buf))) > 0 ||
-		(len == -1 && counter > 0 && (errno == EINTR || errno == EAGAIN))) {
-
+	while ((len = read(fd, buf, sizeof(buf))) > 0 ||
+	       (len == -1 && counter > 0 &&
+		(errno == EINTR || errno == EAGAIN))) {
 		if (len == -1) {
 			counter--;
 			ms_sleep(100);
@@ -151,16 +156,16 @@ ssize_t cstp_send_file(worker_st *ws, const char *file)
 	return total;
 }
 
-static
-int recv_remaining(int fd, uint8_t *p, int left)
+static int recv_remaining(int fd, uint8_t *p, int left)
 {
 	int counter = 100; /* allow 10 seconds for a full packet */
-	unsigned total = 0;
+	unsigned int total = 0;
 	int ret;
 
 	while (left > 0) {
 		ret = recv(fd, p, left, 0);
-		if (ret == -1 && counter > 0 && (errno == EINTR || errno == EAGAIN)) {
+		if (ret == -1 && counter > 0 &&
+		    (errno == EINTR || errno == EAGAIN)) {
 			counter--;
 			ms_sleep(100);
 			continue;
@@ -195,7 +200,7 @@ static ssize_t _cstp_recv_packet(worker_st *ws, void *data, size_t data_size)
 		 * incomplete CSTP packet. In that case we attempt to read
 		 * a full CSTP packet.
 		 */
-		unsigned pktlen;
+		unsigned int pktlen;
 		uint8_t *p = data;
 
 		/* read the header */
@@ -205,18 +210,18 @@ static ssize_t _cstp_recv_packet(worker_st *ws, void *data, size_t data_size)
 
 		/* get the actual length from headers */
 		pktlen = (p[4] << 8) + p[5];
-		if (pktlen+8 > data_size) {
+		if (pktlen + 8 > data_size) {
 			oclog(ws, LOG_ERR, "error in CSTP packet length");
 			return GNUTLS_E_UNEXPECTED_PACKET_LENGTH;
 		}
 
 		if (pktlen > 0) {
-			ret = recv_remaining(ws->conn_fd, p+8, pktlen);
+			ret = recv_remaining(ws->conn_fd, p + 8, pktlen);
 			if (ret <= 0)
 				return ret;
 		}
 
-		return 8+pktlen;
+		return 8 + pktlen;
 	}
 }
 
@@ -255,11 +260,14 @@ ssize_t cstp_recv(worker_st *ws, void *data, size_t data_size)
 	if (ws->session != NULL) {
 		do {
 			ret = gnutls_record_recv(ws->session, data, data_size);
-			if (ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED) {
+			if (ret == GNUTLS_E_AGAIN ||
+			    ret == GNUTLS_E_INTERRUPTED) {
 				counter--;
 				ms_sleep(20);
 			}
-		} while ((ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED) && counter > 0);
+		} while ((ret == GNUTLS_E_AGAIN ||
+			  ret == GNUTLS_E_INTERRUPTED) &&
+			 counter > 0);
 	} else {
 		do {
 			ret = recv(ws->conn_fd, data, data_size, 0);
@@ -267,20 +275,20 @@ ssize_t cstp_recv(worker_st *ws, void *data, size_t data_size)
 				counter--;
 				ms_sleep(20);
 			}
-		} while (ret == -1 && (errno == EINTR || errno == EAGAIN) && counter > 0);
+		} while (ret == -1 && (errno == EINTR || errno == EAGAIN) &&
+			 counter > 0);
 	}
 
 	return ret;
 }
 
-
 /* Typically used in a resumed session. It will return
  * true if a certificate has been used.
  */
-unsigned tls_has_session_cert(struct worker_st * ws)
+unsigned int tls_has_session_cert(struct worker_st *ws)
 {
 	unsigned int list_size = 0;
-	const gnutls_datum_t * certs;
+	const gnutls_datum_t *certs;
 
 	if (ws->session == NULL)
 		return 0;
@@ -299,8 +307,8 @@ unsigned tls_has_session_cert(struct worker_st * ws)
 	return 0;
 }
 
-int __attribute__ ((format(printf, 2, 3)))
-    cstp_printf(worker_st *ws, const char *fmt, ...)
+int __attribute__((format(printf, 2, 3))) cstp_printf(worker_st *ws,
+						      const char *fmt, ...)
 {
 	char *buf;
 	va_list args;
@@ -328,8 +336,7 @@ void cstp_close(worker_st *ws)
 	}
 }
 
-void cstp_fatal_close(worker_st *ws,
-			    gnutls_alert_description_t a)
+void cstp_fatal_close(worker_st *ws, gnutls_alert_description_t a)
 {
 	if (ws->session) {
 		gnutls_alert_send(ws->session, GNUTLS_AL_FATAL, a);
@@ -353,8 +360,8 @@ ssize_t dtls_recv_packet(struct dtls_st *dtls, gnutls_datum_t *data, void **p)
 		data->size = 0;
 	}
 #else
-	ret =
-	    gnutls_record_recv(dtls->dtls_session, ws->buffer, ws->buffer_size);
+	ret = gnutls_record_recv(dtls->dtls_session, ws->buffer,
+				 ws->buffer_size);
 	data->data = ws->buffer;
 	data->size = ret;
 #endif
@@ -362,17 +369,17 @@ ssize_t dtls_recv_packet(struct dtls_st *dtls, gnutls_datum_t *data, void **p)
 	return ret;
 }
 
-ssize_t dtls_send(struct dtls_st *dtls, const void *data,
-			size_t data_size)
+ssize_t dtls_send(struct dtls_st *dtls, const void *data, size_t data_size)
 {
 	int ret;
 	int left = data_size;
-	const uint8_t* p = data;
+	const uint8_t *p = data;
 
 	while (left > 0) {
 		ret = gnutls_record_send(dtls->dtls_session, p, data_size);
 		if (ret < 0) {
-			if (ret != GNUTLS_E_AGAIN && ret != GNUTLS_E_INTERRUPTED) {
+			if (ret != GNUTLS_E_AGAIN &&
+			    ret != GNUTLS_E_INTERRUPTED) {
 				return ret;
 			} else {
 				/* do not cause mayhem */
@@ -402,7 +409,7 @@ static size_t rehash(const void *_e, void *unused)
 	return hash_any(e->session_id, e->session_id_size, 0);
 }
 
-void tls_cache_init(void *pool, tls_sess_db_st* db)
+void tls_cache_init(void *pool, tls_sess_db_st *db)
 {
 	db->ht = talloc(pool, struct htable);
 	if (db->ht == NULL)
@@ -412,23 +419,24 @@ void tls_cache_init(void *pool, tls_sess_db_st* db)
 	db->entries = 0;
 }
 
-void tls_cache_deinit(tls_sess_db_st* db)
+void tls_cache_deinit(tls_sess_db_st *db)
 {
-	tls_cache_st* cache;
+	tls_cache_st *cache;
 	struct htable_iter iter;
 
 	cache = htable_first(db->ht, &iter);
 	while (cache != NULL) {
 		if (cache->session_data_size > 0) {
-			safe_memset(cache->session_data, 0, cache->session_data_size);
+			safe_memset(cache->session_data, 0,
+				    cache->session_data_size);
 			cache->session_data_size = 0;
 			cache->session_id_size = 0;
 		}
 		talloc_free(cache);
 
 		cache = htable_next(db->ht, &iter);
-        }
-        htable_clear(db->ht);
+	}
+	htable_clear(db->ht);
 	db->entries = 0;
 	talloc_free(db->ht);
 }
@@ -442,7 +450,7 @@ static void tls_log_func(int level, const char *str)
 
 static void tls_audit_log_func(gnutls_session_t session, const char *str)
 {
-	worker_st * ws;
+	worker_st *ws;
 
 	(void)(ws);
 
@@ -460,17 +468,19 @@ static int verify_certificate_cb(gnutls_session_t session)
 {
 	unsigned int status;
 	int ret;
-	worker_st * ws;
+	worker_st *ws;
 
 	ws = gnutls_session_get_ptr(session);
 	if (ws == NULL) {
-		oc_syslog(LOG_ERR, "%s:%d: could not obtain worker state", __func__, __LINE__);
+		oc_syslog(LOG_ERR, "%s:%d: could not obtain worker state",
+			  __func__, __LINE__);
 		return -1;
 	}
 
 	if ((session == DTLS_ACTIVE(ws)->dtls_session) ||
-		(session == DTLS_INACTIVE(ws)->dtls_session)) {
-		oclog(ws, LOG_ERR, "unexpected issue; client shouldn't have offered a certificate in DTLS");
+	    (session == DTLS_INACTIVE(ws)->dtls_session)) {
+		oclog(ws, LOG_ERR,
+		      "unexpected issue; client shouldn't have offered a certificate in DTLS");
 		return GNUTLS_E_CERTIFICATE_ERROR;
 	}
 
@@ -480,11 +490,13 @@ static int verify_certificate_cb(gnutls_session_t session)
 	if (ws->cert_username[0] != 0) {
 		char prev_username[MAX_USERNAME_SIZE];
 		const gnutls_datum_t *cert;
-		unsigned cert_size;
+		unsigned int cert_size;
 
 		cert = gnutls_certificate_get_peers(session, &cert_size);
-		if (cert != NULL) { /* it's ok for the user not to send any certificate on renegotiation */
-			memcpy(prev_username, ws->cert_username, MAX_USERNAME_SIZE);
+		if (cert !=
+		    NULL) { /* it's ok for the user not to send any certificate on renegotiation */
+			memcpy(prev_username, ws->cert_username,
+			       MAX_USERNAME_SIZE);
 			ret = get_cert_names(ws, &cert[0]);
 			if (ret < 0) {
 				oclog(ws, LOG_ERR, "cannot parse certificate");
@@ -492,7 +504,8 @@ static int verify_certificate_cb(gnutls_session_t session)
 			}
 
 			if (strcmp(prev_username, ws->cert_username) != 0) {
-				oclog(ws, LOG_ERR, "user switched during renegotiation!");
+				oclog(ws, LOG_ERR,
+				      "user switched during renegotiation!");
 				return GNUTLS_E_CERTIFICATE_ERROR;
 			}
 		}
@@ -507,7 +520,8 @@ static int verify_certificate_cb(gnutls_session_t session)
 		goto no_cert;
 	}
 	if (ret < 0) {
-		oclog(ws, LOG_ERR, "error verifying client certificate: %s", gnutls_strerror(ret));
+		oclog(ws, LOG_ERR, "error verifying client certificate: %s",
+		      gnutls_strerror(ret));
 		goto fail;
 	}
 
@@ -515,26 +529,28 @@ static int verify_certificate_cb(gnutls_session_t session)
 		gnutls_datum_t out;
 		int type = gnutls_certificate_type_get(session);
 
-		ret =
-		    gnutls_certificate_verification_status_print(status, type,
-							 &out, 0);
+		ret = gnutls_certificate_verification_status_print(status, type,
+								   &out, 0);
 		if (ret < 0)
 			goto fail;
 
-		oclog(ws, LOG_INFO, "client certificate verification failed: %s", out.data);
+		oclog(ws, LOG_INFO,
+		      "client certificate verification failed: %s", out.data);
 
 		gnutls_free(out.data);
 
 		goto fail;
 	} else {
 		ws->cert_auth_ok = 1;
-		oclog(ws, LOG_INFO, "client certificate verification succeeded");
+		oclog(ws, LOG_INFO,
+		      "client certificate verification succeeded");
 	}
 
 	/* notify gnutls to continue handshake normally */
 	return 0;
 no_cert:
-	if (WSCONFIG(ws)->cisco_client_compat != 0 || WSCONFIG(ws)->cert_req != GNUTLS_CERT_REQUIRE)
+	if (WSCONFIG(ws)->cisco_client_compat != 0 ||
+	    WSCONFIG(ws)->cert_req != GNUTLS_CERT_REQUIRE)
 		return 0;
 fail:
 	return GNUTLS_E_CERTIFICATE_ERROR;
@@ -576,13 +592,14 @@ void tls_vhost_deinit(struct vhost_cfg_st *vhost)
 #ifndef UNDER_TEST
 /* Checks, if there is a single certificate specified, whether it
  * is compatible with all ciphersuites */
-static void certificate_check(main_server_st *s, const char *vhostname, gnutls_pcert_st *pcert)
+static void certificate_check(main_server_st *s, const char *vhostname,
+			      gnutls_pcert_st *pcert)
 {
-	gnutls_datum_t data = {NULL, 0};
+	gnutls_datum_t data = { NULL, 0 };
 	gnutls_x509_crt_t crt = NULL;
 	int ret;
-	unsigned usage;
-	gnutls_datum_t dn = {NULL, 0};
+	unsigned int usage;
+	gnutls_datum_t dn = { NULL, 0 };
 	const char *cert_name = "unnamed";
 	time_t t;
 
@@ -604,13 +621,15 @@ static void certificate_check(main_server_st *s, const char *vhostname, gnutls_p
 	ret = gnutls_x509_crt_get_dn2(crt, &dn);
 #endif
 	if (ret >= 0) {
-		cert_name = (char*)dn.data;
+		cert_name = (char *)dn.data;
 	}
 
 	ret = gnutls_x509_crt_get_key_usage(crt, &usage, NULL);
 	if (ret >= 0) {
 		if (!(usage & GNUTLS_KEY_KEY_ENCIPHERMENT)) {
-			oc_syslog(LOG_WARNING, "%s certificate key usage prevents key encipherment; unable to support the RSA ciphersuites; "
+			oc_syslog(
+				LOG_WARNING,
+				"%s certificate key usage prevents key encipherment; unable to support the RSA ciphersuites; "
 				"if that is not intentional, regenerate the server certificate with the key usage flag 'key encipherment' set.",
 				cert_name);
 		}
@@ -619,19 +638,24 @@ static void certificate_check(main_server_st *s, const char *vhostname, gnutls_p
 	if (vhostname) {
 		/* check whether the hostname matches our vhost */
 		if (!gnutls_x509_crt_check_hostname(crt, vhostname)) {
-			oc_syslog(LOG_WARNING, "The %s certificate's name doesn't match for vhost %s",
-			      cert_name, vhostname);
+			oc_syslog(
+				LOG_WARNING,
+				"The %s certificate's name doesn't match for vhost %s",
+				cert_name, vhostname);
 		}
 	}
 
 	t = gnutls_x509_crt_get_expiration_time(crt);
 	if (t < time(NULL)) {
-		oc_syslog(LOG_WARNING, "The %s certificate set is expired!", cert_name);
+		oc_syslog(LOG_WARNING, "The %s certificate set is expired!",
+			  cert_name);
 	}
 
 	t = gnutls_x509_crt_get_activation_time(crt);
 	if (t > time(NULL)) {
-		oc_syslog(LOG_WARNING, "The %s certificate set is not yet active!", cert_name);
+		oc_syslog(LOG_WARNING,
+			  "The %s certificate set is not yet active!",
+			  cert_name);
 	}
 
 cleanup:
@@ -641,49 +665,55 @@ cleanup:
 	gnutls_free(dn.data);
 }
 
-static void set_dh_params(main_server_st* s, struct vhost_cfg_st *vhost)
+static void set_dh_params(main_server_st *s, struct vhost_cfg_st *vhost)
 {
 	gnutls_datum_t data;
 	int ret;
 
 	if (vhost->perm_config.dh_params_file != NULL) {
-		ret = gnutls_dh_params_init (&vhost->creds.dh_params);
+		ret = gnutls_dh_params_init(&vhost->creds.dh_params);
 		GNUTLS_FATAL_ERR(ret);
 
-		ret = gnutls_load_file(vhost->perm_config.dh_params_file, &data);
+		ret = gnutls_load_file(vhost->perm_config.dh_params_file,
+				       &data);
 		GNUTLS_FATAL_ERR(ret);
 
-		ret = gnutls_dh_params_import_pkcs3(vhost->creds.dh_params, &data, GNUTLS_X509_FMT_PEM);
+		ret = gnutls_dh_params_import_pkcs3(vhost->creds.dh_params,
+						    &data, GNUTLS_X509_FMT_PEM);
 		GNUTLS_FATAL_ERR(ret);
 
 		gnutls_free(data.data);
 
-		gnutls_certificate_set_dh_params(vhost->creds.xcred, vhost->creds.dh_params);
+		gnutls_certificate_set_dh_params(vhost->creds.xcred,
+						 vhost->creds.dh_params);
 	} else {
 #if GNUTLS_VERSION_NUMBER >= 0x030506
 		/* use pre-generated parameters */
-		gnutls_certificate_set_known_dh_params(vhost->creds.xcred, GNUTLS_SEC_PARAM_MEDIUM);
+		gnutls_certificate_set_known_dh_params(vhost->creds.xcred,
+						       GNUTLS_SEC_PARAM_MEDIUM);
 #endif
 	}
 }
 
 struct key_cb_data {
-	unsigned pk;
-	unsigned bits;
-	unsigned idx; /* the index of the key */
+	unsigned int pk;
+	unsigned int bits;
+	unsigned int idx; /* the index of the key */
 	struct sockaddr_un sa;
-	unsigned sa_len;
+	unsigned int sa_len;
 	const char *vhost;
 };
 
-static
-int key_cb_common_func (gnutls_privkey_t key, void* userdata, const gnutls_datum_t * raw_data,
-	gnutls_datum_t * output, unsigned sigalgo, unsigned type)
+static int key_cb_common_func(gnutls_privkey_t key, void *userdata,
+			      const gnutls_datum_t *raw_data,
+			      gnutls_datum_t *output, unsigned int sigalgo,
+			      unsigned int type)
 {
-	struct key_cb_data* cdata = userdata;
+	struct key_cb_data *cdata = userdata;
 	int sd = -1, ret, e;
 	SecOpMsg msg = SEC_OP_MSG__INIT;
 	SecOpMsg *reply = NULL;
+
 	PROTOBUF_ALLOCATOR(pa, userdata);
 
 	output->data = NULL;
@@ -700,8 +730,9 @@ int key_cb_common_func (gnutls_privkey_t key, void* userdata, const gnutls_datum
 	ret = connect(sd, (struct sockaddr *)&cdata->sa, cdata->sa_len);
 	if (ret == -1) {
 		e = errno;
-		oc_syslog(LOG_DEBUG, "error connecting to sec-mod socket '%s': %s",
-			cdata->sa.sun_path, strerror(e));
+		oc_syslog(LOG_DEBUG,
+			  "error connecting to sec-mod socket '%s': %s",
+			  cdata->sa.sun_path, strerror(e));
 		goto error;
 	}
 
@@ -710,22 +741,21 @@ int key_cb_common_func (gnutls_privkey_t key, void* userdata, const gnutls_datum
 	msg.sig = sigalgo;
 	msg.data.data = raw_data->data;
 	msg.data.len = raw_data->size;
-	msg.vhost = (char*)cdata->vhost;
+	msg.vhost = (char *)cdata->vhost;
 
 	ret = send_msg(userdata, sd, type, &msg,
-			(pack_size_func)sec_op_msg__get_packed_size,
-			(pack_func)sec_op_msg__pack);
+		       (pack_size_func)sec_op_msg__get_packed_size,
+		       (pack_func)sec_op_msg__pack);
 	if (ret < 0) {
 		goto error;
 	}
 
-	ret = recv_msg(userdata, sd, type, (void*)&reply,
-		       (unpack_func)sec_op_msg__unpack,
-		       DEFAULT_SOCKET_TIMEOUT);
+	ret = recv_msg(userdata, sd, type, (void *)&reply,
+		       (unpack_func)sec_op_msg__unpack, DEFAULT_SOCKET_TIMEOUT);
 	if (ret < 0) {
 		e = errno;
 		oc_syslog(LOG_ERR, "error receiving sec-mod reply: %s",
-				strerror(e));
+			  strerror(e));
 		goto error;
 	}
 	close(sd);
@@ -753,7 +783,8 @@ error:
 }
 
 #if GNUTLS_VERSION_NUMBER >= 0x030600
-static int key_cb_info_func(gnutls_privkey_t key, unsigned int flags, void *userdata)
+static int key_cb_info_func(gnutls_privkey_t key, unsigned int flags,
+			    void *userdata)
 {
 	struct key_cb_data *p = userdata;
 
@@ -764,7 +795,7 @@ static int key_cb_info_func(gnutls_privkey_t key, unsigned int flags, void *user
 		return p->bits;
 #endif
 	} else if (flags & GNUTLS_PRIVKEY_INFO_HAVE_SIGN_ALGO) {
-		unsigned sig = GNUTLS_FLAGS_TO_SIGN_ALGO(flags);
+		unsigned int sig = GNUTLS_FLAGS_TO_SIGN_ALGO(flags);
 
 		if (gnutls_sign_supports_pk_algorithm(sig, p->pk))
 			return 1;
@@ -775,83 +806,98 @@ static int key_cb_info_func(gnutls_privkey_t key, unsigned int flags, void *user
 	return -1;
 }
 
-static
-int key_cb_sign_data_func (gnutls_privkey_t key, gnutls_sign_algorithm_t sig,
-			   void* userdata, unsigned int flags, const gnutls_datum_t *data,
-			   gnutls_datum_t *signature)
+static int key_cb_sign_data_func(gnutls_privkey_t key,
+				 gnutls_sign_algorithm_t sig, void *userdata,
+				 unsigned int flags, const gnutls_datum_t *data,
+				 gnutls_datum_t *signature)
 {
-	return key_cb_common_func(key, userdata, data, signature, sig, CMD_SEC_SIGN_DATA);
+	return key_cb_common_func(key, userdata, data, signature, sig,
+				  CMD_SEC_SIGN_DATA);
 }
 
-static
-int key_cb_sign_hash_func (gnutls_privkey_t key, gnutls_sign_algorithm_t sig,
-			   void* userdata, unsigned int flags, const gnutls_datum_t *data,
-			   gnutls_datum_t *signature)
+static int key_cb_sign_hash_func(gnutls_privkey_t key,
+				 gnutls_sign_algorithm_t sig, void *userdata,
+				 unsigned int flags, const gnutls_datum_t *data,
+				 gnutls_datum_t *signature)
 {
 	if (sig == GNUTLS_SIGN_RSA_RAW)
-		return key_cb_common_func(key, userdata, data, signature, 0, CMD_SEC_SIGN);
+		return key_cb_common_func(key, userdata, data, signature, 0,
+					  CMD_SEC_SIGN);
 
-	return key_cb_common_func(key, userdata, data, signature, sig, CMD_SEC_SIGN_HASH);
+	return key_cb_common_func(key, userdata, data, signature, sig,
+				  CMD_SEC_SIGN_HASH);
 }
 
 #else
-static
-int key_cb_sign_func (gnutls_privkey_t key, void* userdata, const gnutls_datum_t * raw_data,
-	gnutls_datum_t * signature)
+static int key_cb_sign_func(gnutls_privkey_t key, void *userdata,
+			    const gnutls_datum_t *raw_data,
+			    gnutls_datum_t *signature)
 {
-	return key_cb_common_func(key, userdata, raw_data, signature, 0, CMD_SEC_SIGN);
+	return key_cb_common_func(key, userdata, raw_data, signature, 0,
+				  CMD_SEC_SIGN);
 }
 #endif
 
-static int key_cb_decrypt_func(gnutls_privkey_t key, void* userdata, const gnutls_datum_t * ciphertext,
-	gnutls_datum_t * plaintext)
+static int key_cb_decrypt_func(gnutls_privkey_t key, void *userdata,
+			       const gnutls_datum_t *ciphertext,
+			       gnutls_datum_t *plaintext)
 {
-	return key_cb_common_func(key, userdata, ciphertext, plaintext, 0, CMD_SEC_DECRYPT);
+	return key_cb_common_func(key, userdata, ciphertext, plaintext, 0,
+				  CMD_SEC_DECRYPT);
 }
 
-static void key_cb_deinit_func(gnutls_privkey_t key, void* userdata)
+static void key_cb_deinit_func(gnutls_privkey_t key, void *userdata)
 {
 	talloc_free(userdata);
 }
 
-static
-int load_cert_files(main_server_st *s, struct vhost_cfg_st *vhost)
+static int load_cert_files(main_server_st *s, struct vhost_cfg_st *vhost)
 {
 	int ret;
 	gnutls_pcert_st *pcert_list;
-	unsigned pcert_list_size, i;
+	unsigned int pcert_list_size, i;
 	gnutls_privkey_t key;
 	gnutls_datum_t data;
 	struct key_cb_data *cdata;
-	unsigned flags;
+	unsigned int flags;
 
-	for (i=0;i<vhost->perm_config.key_size;i++) {
+	for (i = 0; i < vhost->perm_config.key_size; i++) {
 		/* load the certificate */
 
 		if (gnutls_url_is_supported(vhost->perm_config.cert[i]) != 0) {
-			oc_syslog(LOG_ERR, "Loading a certificate from '%s' is unsupported", vhost->perm_config.cert[i]);
+			oc_syslog(
+				LOG_ERR,
+				"Loading a certificate from '%s' is unsupported",
+				vhost->perm_config.cert[i]);
 			return -1;
 		} else {
-			ret = gnutls_load_file(vhost->perm_config.cert[i], &data);
+			ret = gnutls_load_file(vhost->perm_config.cert[i],
+					       &data);
 			if (ret < 0) {
-				oc_syslog(LOG_ERR, "error loading file[%d] '%s'", i, vhost->perm_config.cert[i]);
+				oc_syslog(LOG_ERR,
+					  "error loading file[%d] '%s'", i,
+					  vhost->perm_config.cert[i]);
 				return -1;
 			}
 
 			pcert_list_size = 8;
-			pcert_list = talloc_size(vhost->pool, sizeof(pcert_list[0])*pcert_list_size);
+			pcert_list = talloc_size(vhost->pool,
+						 sizeof(pcert_list[0]) *
+							 pcert_list_size);
 			if (pcert_list == NULL) {
 				oc_syslog(LOG_ERR, "error allocating memory");
 				return -1;
 			}
 
-			flags = GNUTLS_X509_CRT_LIST_FAIL_IF_UNSORTED|GNUTLS_X509_CRT_LIST_IMPORT_FAIL_IF_EXCEED;
+			flags = GNUTLS_X509_CRT_LIST_FAIL_IF_UNSORTED |
+				GNUTLS_X509_CRT_LIST_IMPORT_FAIL_IF_EXCEED;
 #if GNUTLS_VERSION_NUMBER > 0x030409
 			flags |= GNUTLS_X509_CRT_LIST_SORT;
 #endif
 
-			ret = gnutls_pcert_list_import_x509_raw(pcert_list, &pcert_list_size,
-								&data, GNUTLS_X509_FMT_PEM, flags);
+			ret = gnutls_pcert_list_import_x509_raw(
+				pcert_list, &pcert_list_size, &data,
+				GNUTLS_X509_FMT_PEM, flags);
 			GNUTLS_FATAL_ERR(ret);
 
 			gnutls_free(data.data);
@@ -877,34 +923,41 @@ int load_cert_files(main_server_st *s, struct vhost_cfg_st *vhost)
 
 		/* when called here configuration may not be populated, so avoid using it */
 		cdata->sa.sun_family = AF_UNIX;
-		strlcpy(cdata->sa.sun_path, secmod_socket_file_name(&vhost->perm_config), sizeof(cdata->sa.sun_path));
+		strlcpy(cdata->sa.sun_path,
+			secmod_socket_file_name(&vhost->perm_config),
+			sizeof(cdata->sa.sun_path));
 		cdata->sa_len = SUN_LEN(&cdata->sa);
 
-
 		/* load the private key */
 
 #if GNUTLS_VERSION_NUMBER >= 0x030600
-		cdata->pk = gnutls_pubkey_get_pk_algorithm(pcert_list[0].pubkey, &cdata->bits);
-		ret = gnutls_privkey_import_ext4(key, cdata, key_cb_sign_data_func,
-			key_cb_sign_hash_func,key_cb_decrypt_func,
+		cdata->pk = gnutls_pubkey_get_pk_algorithm(pcert_list[0].pubkey,
+							   &cdata->bits);
+		ret = gnutls_privkey_import_ext4(
+			key, cdata, key_cb_sign_data_func,
+			key_cb_sign_hash_func, key_cb_decrypt_func,
 			key_cb_deinit_func, key_cb_info_func,
 			GNUTLS_PRIVKEY_IMPORT_AUTO_RELEASE);
 #else
-		ret = gnutls_privkey_import_ext2(key, gnutls_pubkey_get_pk_algorithm(pcert_list[0].pubkey, NULL),
+		ret = gnutls_privkey_import_ext2(
+			key,
+			gnutls_pubkey_get_pk_algorithm(pcert_list[0].pubkey,
+						       NULL),
 			cdata, key_cb_sign_func, key_cb_decrypt_func,
 			key_cb_deinit_func, GNUTLS_PRIVKEY_IMPORT_AUTO_RELEASE);
 #endif
 		GNUTLS_FATAL_ERR(ret);
 
-		ret = gnutls_certificate_set_key(vhost->creds.xcred, NULL, 0, pcert_list,
-				pcert_list_size, key);
+		ret = gnutls_certificate_set_key(vhost->creds.xcred, NULL, 0,
+						 pcert_list, pcert_list_size,
+						 key);
 		GNUTLS_FATAL_ERR(ret);
 	}
 
 	return 0;
 }
 
-unsigned need_file_reload(const char *file, time_t last_access)
+unsigned int need_file_reload(const char *file, time_t last_access)
 {
 	struct stat st;
 	int ret, e;
@@ -918,8 +971,9 @@ unsigned need_file_reload(const char *file, time_t last_access)
 	ret = stat(file, &st);
 	if (ret == -1) {
 		e = errno;
-		oc_syslog(LOG_INFO, "file %s (to be reloaded) was not found: %s",
-		      file, strerror(e));
+		oc_syslog(LOG_INFO,
+			  "file %s (to be reloaded) was not found: %s", file,
+			  strerror(e));
 		return 0;
 	}
 
@@ -932,23 +986,28 @@ unsigned need_file_reload(const char *file, time_t last_access)
 /* reload key files etc.
  * @s may be %NULL, and should be used for mslog() purposes only.
  */
-void tls_load_files(main_server_st *s, struct vhost_cfg_st *vhost, unsigned silent)
+void tls_load_files(main_server_st *s, struct vhost_cfg_st *vhost,
+		    unsigned int silent)
 {
 	int ret;
-	unsigned i;
-	unsigned need_reload = 0;
+	unsigned int i;
+	unsigned int need_reload = 0;
 
 	if (vhost->params_last_access != 0) {
-		for (i=0;i<vhost->perm_config.key_size;i++) {
-			if (need_file_reload(vhost->perm_config.cert[i], vhost->params_last_access) != 0) {
+		for (i = 0; i < vhost->perm_config.key_size; i++) {
+			if (need_file_reload(vhost->perm_config.cert[i],
+					     vhost->params_last_access) != 0) {
 				need_reload = 1;
 				break;
 			}
 		}
 
-		if (need_file_reload(vhost->perm_config.ca, vhost->params_last_access) ||
-		    need_file_reload(vhost->perm_config.config->ocsp_response, vhost->params_last_access) ||
-		    need_file_reload(vhost->perm_config.dh_params_file, vhost->params_last_access)) {
+		if (need_file_reload(vhost->perm_config.ca,
+				     vhost->params_last_access) ||
+		    need_file_reload(vhost->perm_config.config->ocsp_response,
+				     vhost->params_last_access) ||
+		    need_file_reload(vhost->perm_config.dh_params_file,
+				     vhost->params_last_access)) {
 			need_reload = 1;
 		}
 
@@ -976,15 +1035,19 @@ void tls_load_files(main_server_st *s, struct vhost_cfg_st *vhost, unsigned sile
 
 	set_dh_params(s, vhost);
 
-	if (vhost->perm_config.key_size == 0 || vhost->perm_config.cert_size == 0) {
-		oc_syslog(LOG_ERR, "no certificate or key files were specified");
+	if (vhost->perm_config.key_size == 0 ||
+	    vhost->perm_config.cert_size == 0) {
+		oc_syslog(LOG_ERR,
+			  "no certificate or key files were specified");
 		exit(EXIT_FAILURE);
 	}
 
 	/* on reload reduce any checks done */
 	if (need_reload) {
 #if GNUTLS_VERSION_NUMBER >= 0x030407
-		gnutls_certificate_set_flags(vhost->creds.xcred, GNUTLS_CERTIFICATE_SKIP_KEY_CERT_MATCH);
+		gnutls_certificate_set_flags(
+			vhost->creds.xcred,
+			GNUTLS_CERTIFICATE_SKIP_KEY_CERT_MATCH);
 #endif
 	}
 
@@ -996,18 +1059,20 @@ void tls_load_files(main_server_st *s, struct vhost_cfg_st *vhost, unsigned sile
 
 	if (vhost->perm_config.config->cert_req != GNUTLS_CERT_IGNORE) {
 		if (vhost->perm_config.ca != NULL) {
-			ret =
-			    gnutls_certificate_set_x509_trust_file(vhost->creds.xcred,
-								   vhost->perm_config.ca,
-								   GNUTLS_X509_FMT_PEM);
+			ret = gnutls_certificate_set_x509_trust_file(
+				vhost->creds.xcred, vhost->perm_config.ca,
+				GNUTLS_X509_FMT_PEM);
 			if (ret < 0) {
-				oc_syslog(LOG_ERR, "error setting the CA (%s) file",
-					vhost->perm_config.ca);
+				oc_syslog(LOG_ERR,
+					  "error setting the CA (%s) file",
+					  vhost->perm_config.ca);
 				exit(EXIT_FAILURE);
 			}
 
 			if (!silent)
-				oc_syslog(LOG_INFO, "processed %d CA certificate(s)", ret);
+				oc_syslog(LOG_INFO,
+					  "processed %d CA certificate(s)",
+					  ret);
 		}
 
 		tls_reload_crl(s, vhost, 1);
@@ -1019,7 +1084,8 @@ void tls_load_files(main_server_st *s, struct vhost_cfg_st *vhost, unsigned sile
 	tls_reload_ocsp(s, vhost);
 }
 
-static int ocsp_get_func(gnutls_session_t session, void *ptr, gnutls_datum_t *response)
+static int ocsp_get_func(gnutls_session_t session, void *ptr,
+			 gnutls_datum_t *response)
 {
 	struct vhost_cfg_st *vhost = ptr;
 
@@ -1030,13 +1096,14 @@ static int ocsp_get_func(gnutls_session_t session, void *ptr, gnutls_datum_t *re
 	if (response->data == NULL)
 		return GNUTLS_E_NO_CERTIFICATE_STATUS;
 
-	memcpy(response->data, vhost->creds.ocsp_response.data, vhost->creds.ocsp_response.size);
+	memcpy(response->data, vhost->creds.ocsp_response.data,
+	       vhost->creds.ocsp_response.size);
 	response->size = vhost->creds.ocsp_response.size;
 
 	return 0;
 }
 
-static void tls_reload_ocsp(main_server_st* s, struct vhost_cfg_st *vhost)
+static void tls_reload_ocsp(main_server_st *s, struct vhost_cfg_st *vhost)
 {
 	int ret;
 
@@ -1044,14 +1111,16 @@ static void tls_reload_ocsp(main_server_st* s, struct vhost_cfg_st *vhost)
 	vhost->creds.ocsp_response.data = NULL;
 
 	if (vhost->perm_config.config->ocsp_response != NULL) {
-		ret = gnutls_load_file(vhost->perm_config.config->ocsp_response, &vhost->creds.ocsp_response);
+		ret = gnutls_load_file(vhost->perm_config.config->ocsp_response,
+				       &vhost->creds.ocsp_response);
 		if (ret < 0)
 			return;
 
-		gnutls_certificate_set_ocsp_status_request_function(vhost->creds.xcred,
-								    ocsp_get_func, vhost);
+		gnutls_certificate_set_ocsp_status_request_function(
+			vhost->creds.xcred, ocsp_get_func, vhost);
 	} else {
-		gnutls_certificate_set_ocsp_status_request_function(vhost->creds.xcred, NULL, 0);
+		gnutls_certificate_set_ocsp_status_request_function(
+			vhost->creds.xcred, NULL, 0);
 	}
 }
 
@@ -1061,12 +1130,14 @@ static void tls_reload_ocsp(main_server_st* s, struct vhost_cfg_st *vhost)
 void tls_load_prio(main_server_st *s, struct vhost_cfg_st *vhost)
 {
 	int ret;
-	const char* perr;
+	const char *perr;
 
 	if (vhost->creds.cprio != NULL)
 		gnutls_priority_deinit(vhost->creds.cprio);
 
-	ret = gnutls_priority_init(&vhost->creds.cprio, vhost->perm_config.config->priorities, &perr);
+	ret = gnutls_priority_init(&vhost->creds.cprio,
+				   vhost->perm_config.config->priorities,
+				   &perr);
 	if (ret == GNUTLS_E_PARSING_ERROR)
 		oc_syslog(LOG_ERR, "error in TLS priority string: %s", perr);
 	GNUTLS_FATAL_ERR(ret);
@@ -1075,43 +1146,49 @@ void tls_load_prio(main_server_st *s, struct vhost_cfg_st *vhost)
 /*
  * @s may be %NULL, and should be used for mslog() purposes only.
  */
-void tls_reload_crl(main_server_st* s, struct vhost_cfg_st *vhost, unsigned force)
+void tls_reload_crl(main_server_st *s, struct vhost_cfg_st *vhost,
+		    unsigned int force)
 {
 	int ret, saved_ret;
-	static unsigned crl_type = GNUTLS_X509_FMT_PEM;
+	static unsigned int crl_type = GNUTLS_X509_FMT_PEM;
 
 	if (force)
 		vhost->crl_last_access = 0;
 
-	if (vhost->perm_config.config->cert_req != GNUTLS_CERT_IGNORE && vhost->perm_config.config->crl != NULL) {
-		if (need_file_reload(vhost->perm_config.config->crl, vhost->crl_last_access) == 0) {
-			oc_syslog(LOG_DEBUG, "skipping already loaded CRL: %s", vhost->perm_config.config->crl);
+	if (vhost->perm_config.config->cert_req != GNUTLS_CERT_IGNORE &&
+	    vhost->perm_config.config->crl != NULL) {
+		if (need_file_reload(vhost->perm_config.config->crl,
+				     vhost->crl_last_access) == 0) {
+			oc_syslog(LOG_DEBUG, "skipping already loaded CRL: %s",
+				  vhost->perm_config.config->crl);
 			return;
 		}
 
 		vhost->crl_last_access = time(NULL);
 
-		ret =
-		    gnutls_certificate_set_x509_crl_file(vhost->creds.xcred,
-							 vhost->perm_config.config->crl,
-							 crl_type);
-		if (ret == GNUTLS_E_BASE64_DECODING_ERROR && crl_type == GNUTLS_X509_FMT_PEM) {
+		ret = gnutls_certificate_set_x509_crl_file(
+			vhost->creds.xcred, vhost->perm_config.config->crl,
+			crl_type);
+		if (ret == GNUTLS_E_BASE64_DECODING_ERROR &&
+		    crl_type == GNUTLS_X509_FMT_PEM) {
 			crl_type = GNUTLS_X509_FMT_DER;
 			saved_ret = ret;
-			ret =
-			    gnutls_certificate_set_x509_crl_file(vhost->creds.xcred,
-								 vhost->perm_config.config->crl,
-								 crl_type);
+			ret = gnutls_certificate_set_x509_crl_file(
+				vhost->creds.xcred,
+				vhost->perm_config.config->crl, crl_type);
 			if (ret < 0)
 				ret = saved_ret;
 		}
 		if (ret < 0) {
 			/* ignore the CRL file when empty */
-			oc_syslog(LOG_ERR, "error reading the CRL (%s) file: %s",
-				vhost->perm_config.config->crl, gnutls_strerror(ret));
+			oc_syslog(LOG_ERR,
+				  "error reading the CRL (%s) file: %s",
+				  vhost->perm_config.config->crl,
+				  gnutls_strerror(ret));
 			exit(EXIT_FAILURE);
 		}
-		oc_syslog(LOG_INFO, "loaded CRL: %s", vhost->perm_config.config->crl);
+		oc_syslog(LOG_INFO, "loaded CRL: %s",
+			  vhost->perm_config.config->crl);
 	}
 }
 #endif /* UNDER_TEST */
@@ -1126,14 +1203,14 @@ int tls_uncork(gnutls_session_t session)
 	return gnutls_record_uncork(session, GNUTLS_RECORD_WAIT);
 }
 
-void *calc_sha1_hash(void *pool, char* file, unsigned cert)
+void *calc_sha1_hash(void *pool, char *file, unsigned int cert)
 {
 	int ret;
 	gnutls_datum_t data;
 	uint8_t digest[20];
-	char * retval;
+	char *retval;
 	gnutls_x509_crt_t crt;
-	unsigned i;
+	unsigned int i;
 
 	ret = gnutls_load_file(file, &data);
 	if (ret < 0) {
@@ -1146,7 +1223,8 @@ void *calc_sha1_hash(void *pool, char* file, unsigned cert)
 
 		ret = gnutls_x509_crt_import(crt, &data, GNUTLS_X509_FMT_PEM);
 		if (ret == GNUTLS_E_BASE64_DECODING_ERROR)
-			ret = gnutls_x509_crt_import(crt, &data, GNUTLS_X509_FMT_DER);
+			ret = gnutls_x509_crt_import(crt, &data,
+						     GNUTLS_X509_FMT_DER);
 		GNUTLS_FATAL_ERR(ret);
 
 		gnutls_free(data.data);
@@ -1160,11 +1238,13 @@ void *calc_sha1_hash(void *pool, char* file, unsigned cert)
 	gnutls_free(data.data);
 
 	if (ret < 0) {
-		oc_syslog(LOG_ERR, "error calculating hash of '%s': %s", file, gnutls_strerror(ret));
+		oc_syslog(LOG_ERR, "error calculating hash of '%s': %s", file,
+			  gnutls_strerror(ret));
 		exit(EXIT_FAILURE);
 	}
 
-	size_t ret_size = sizeof(digest)*2+1;
+	size_t ret_size = sizeof(digest) * 2 + 1;
+
 	retval = talloc_size(pool, ret_size);
 	if (retval == NULL) {
 		oc_syslog(LOG_ERR, "memory error");
@@ -1175,20 +1255,24 @@ void *calc_sha1_hash(void *pool, char* file, unsigned cert)
 	data.size = sizeof(digest);
 	ret = gnutls_hex_encode(&data, retval, &ret_size);
 	if (ret < 0) {
-		oc_syslog(LOG_ERR, "error in hex encode: %s", gnutls_strerror(ret));
+		oc_syslog(LOG_ERR, "error in hex encode: %s",
+			  gnutls_strerror(ret));
 		exit(EXIT_FAILURE);
 	}
-	if (retval[ret_size-1] == 0) ret_size--; /* remove the null terminator */
+	if (retval[ret_size - 1] == 0)
+		ret_size--; /* remove the null terminator */
 
 	/* convert to all caps */
-	for (i=0;i<ret_size;i++)
-	        retval[i] = toupper(retval[i]);
+	for (i = 0; i < ret_size; i++)
+		retval[i] = toupper(retval[i]);
 
 	return retval;
 }
 
-
-size_t tls_get_overhead(gnutls_protocol_t version, gnutls_cipher_algorithm_t cipher, gnutls_mac_algorithm_t mac)
+size_t tls_get_overhead(gnutls_protocol_t version,
+			gnutls_cipher_algorithm_t cipher,
+			gnutls_mac_algorithm_t mac)
 {
-	return gnutls_est_record_overhead_size(version, cipher, mac, GNUTLS_COMP_NULL, 0);
+	return gnutls_est_record_overhead_size(version, cipher, mac,
+					       GNUTLS_COMP_NULL, 0);
 }
