@@ -19,6 +19,7 @@
 
 #include <config.h>
 
+#include <inttypes.h>
 #include <stdlib.h>
 #include <stdarg.h>
 #include <stdio.h>
@@ -30,13 +31,15 @@
 
 #ifdef HAVE_GSSAPI
 
-int der_decode(const uint8_t *der, unsigned der_size, uint8_t *out, unsigned *out_size,
-	       char *realm, unsigned realm_size, int *error)
+int der_decode(const uint8_t *der, unsigned int der_size, uint8_t *out,
+	       unsigned int *out_size, char *realm, unsigned int realm_size,
+	       int *error)
 {
 	int ret, len;
 	asn1_node c2 = NULL;
 
-	ret = asn1_create_element(_kkdcp_pkix1_asn, "KKDCP.KDC-PROXY-MESSAGE", &c2);
+	ret = asn1_create_element(_kkdcp_pkix1_asn, "KKDCP.KDC-PROXY-MESSAGE",
+				  &c2);
 	if (ret != ASN1_SUCCESS) {
 		*error = ret;
 		return -1;
@@ -66,18 +69,19 @@ int der_decode(const uint8_t *der, unsigned der_size, uint8_t *out, unsigned *ou
 	}
 
 	ret = 0;
- cleanup:
+cleanup:
 	asn1_delete_structure(&c2);
 	return ret;
-
 }
 
-int der_encode_inplace(uint8_t *raw, unsigned *raw_size, unsigned max_size, int *error)
+int der_encode_inplace(uint8_t *raw, unsigned int *raw_size,
+		       unsigned int max_size, int *error)
 {
 	int ret, len;
 	asn1_node c2 = NULL;
 
-	ret = asn1_create_element(_kkdcp_pkix1_asn, "KKDCP.KDC-PROXY-MESSAGE", &c2);
+	ret = asn1_create_element(_kkdcp_pkix1_asn, "KKDCP.KDC-PROXY-MESSAGE",
+				  &c2);
 	if (ret != ASN1_SUCCESS) {
 		*error = ret;
 		return -1;
@@ -104,20 +108,19 @@ int der_encode_inplace(uint8_t *raw, unsigned *raw_size, unsigned max_size, int
 	*raw_size = len;
 
 	ret = 0;
- cleanup:
+cleanup:
 	asn1_delete_structure(&c2);
 	return ret;
-
 }
 
 /* max UDP size */
 #define KKDCP_READ_TIMEOUT 20
-#define BUF_SIZE 64*1024
-int post_kkdcp_handler(worker_st *ws, unsigned http_ver)
+#define BUF_SIZE 64 * 1024
+int post_kkdcp_handler(worker_st *ws, unsigned int http_ver)
 {
 	int ret, e, fd = -1;
 	struct http_req_st *req = &ws->req;
-	unsigned i, length;
+	unsigned int i, length;
 	kkdcp_st *kkdcp = NULL;
 	uint8_t *buf;
 	uint32_t mlength;
@@ -127,25 +130,30 @@ int post_kkdcp_handler(worker_st *ws, unsigned http_ver)
 
 	oclog(ws, LOG_INFO, "Processing KKDCP request");
 
-	for (i=0;i<WSCONFIG(ws)->kkdcp_size;i++) {
-		if (WSCONFIG(ws)->kkdcp[i].url && strcmp(WSCONFIG(ws)->kkdcp[i].url, req->url) == 0) {
+	for (i = 0; i < WSCONFIG(ws)->kkdcp_size; i++) {
+		if (WSCONFIG(ws)->kkdcp[i].url &&
+		    strcmp(WSCONFIG(ws)->kkdcp[i].url, req->url) == 0) {
 			kkdcp = &WSCONFIG(ws)->kkdcp[i];
 			break;
 		}
 	}
 
 	if (kkdcp == NULL) {
-		oclog(ws, LOG_HTTP_DEBUG, "could not figure kkdcp handler for %s", req->url);
+		oclog(ws, LOG_HTTP_DEBUG,
+		      "could not figure kkdcp handler for %s", req->url);
 		return -1;
 	}
 
 	if (req->body_length == 0) {
-		oclog(ws, LOG_HTTP_DEBUG, "empty body length for kkdcp handler %s", req->url);
+		oclog(ws, LOG_HTTP_DEBUG,
+		      "empty body length for kkdcp handler %s", req->url);
 		return -1;
 	}
 
 	ws_add_score_to_ip(ws, WSCONFIG(ws)->ban_points_kkdcp, 0, 0);
-	oclog(ws, LOG_HTTP_DEBUG, "HTTP processing kkdcp framed request: %u bytes", (unsigned)req->body_length);
+	oclog(ws, LOG_HTTP_DEBUG,
+	      "HTTP processing kkdcp framed request: %u bytes",
+	      req->body_length);
 
 	length = BUF_SIZE;
 	buf = talloc_size(ws, length);
@@ -154,9 +162,11 @@ int post_kkdcp_handler(worker_st *ws, unsigned http_ver)
 		return -1;
 	}
 
-	ret = der_decode((uint8_t*)req->body, req->body_length, buf, &length, realm, sizeof(realm), &e);
+	ret = der_decode((uint8_t *)req->body, req->body_length, buf, &length,
+			 realm, sizeof(realm), &e);
 	if (ret < 0) {
-		oclog(ws, LOG_ERR, "kkdcp: DER decoding error: %s", asn1_strerror(e));
+		oclog(ws, LOG_ERR, "kkdcp: DER decoding error: %s",
+		      asn1_strerror(e));
 		reason = "kkdcp: DER decoding error";
 		goto fail;
 	}
@@ -165,7 +175,7 @@ int post_kkdcp_handler(worker_st *ws, unsigned http_ver)
 	if (realm[0] != 0 && kkdcp->realms_size > 1) {
 		oclog(ws, LOG_DEBUG, "kkdcp: client asked for '%s'", realm);
 
-		for (i=0;i<kkdcp->realms_size;i++) {
+		for (i = 0; i < kkdcp->realms_size; i++) {
 			if (strcmp(kkdcp->realms[i].realm, realm) == 0) {
 				kr = &kkdcp->realms[i];
 				break;
@@ -181,7 +191,7 @@ int post_kkdcp_handler(worker_st *ws, unsigned http_ver)
 		goto fail;
 	}
 
-	ret = connect(fd, (struct sockaddr*)&kr->addr, kr->addr_len);
+	ret = connect(fd, (struct sockaddr *)&kr->addr, kr->addr_len);
 	if (ret == -1) {
 		e = errno;
 		oclog(ws, LOG_ERR, "kkdcp: connect error: %s", strerror(e));
@@ -189,14 +199,17 @@ int post_kkdcp_handler(worker_st *ws, unsigned http_ver)
 		goto fail;
 	}
 
-	oclog(ws, LOG_HTTP_DEBUG, "HTTP sending kkdcp request: %u bytes", (unsigned)length);
+	oclog(ws, LOG_HTTP_DEBUG, "HTTP sending kkdcp request: %u bytes",
+	      length);
 	ret = send(fd, buf, length, 0);
 	if (ret != length) {
 		if (ret == -1) {
 			e = errno;
-			oclog(ws, LOG_ERR, "kkdcp: send error: %s", strerror(e));
+			oclog(ws, LOG_ERR, "kkdcp: send error: %s",
+			      strerror(e));
 		} else {
-			oclog(ws, LOG_ERR, "kkdcp: send error: only %d were sent", ret);
+			oclog(ws, LOG_ERR,
+			      "kkdcp: send error: only %d were sent", ret);
 		}
 		reason = "kkdcp: error sending to server";
 		goto fail;
@@ -206,7 +219,8 @@ int post_kkdcp_handler(worker_st *ws, unsigned http_ver)
 		ret = recv(fd, buf, BUF_SIZE, 0);
 		if (ret == -1) {
 			e = errno;
-			oclog(ws, LOG_ERR, "kkdcp: recv error: %s", strerror(e));
+			oclog(ws, LOG_ERR, "kkdcp: recv error: %s",
+			      strerror(e));
 			reason = "kkdcp: error receiving from server";
 			goto fail;
 		}
@@ -216,30 +230,36 @@ int post_kkdcp_handler(worker_st *ws, unsigned http_ver)
 		ret = recv(fd, buf, 4, 0);
 		if (ret < 4) {
 			e = errno;
-			oclog(ws, LOG_ERR, "kkdcp: recv error: %s", strerror(e));
+			oclog(ws, LOG_ERR, "kkdcp: recv error: %s",
+			      strerror(e));
 			reason = "kkdcp: error receiving from server";
 			goto fail;
 		}
 
 		memcpy(&mlength, buf, 4);
 		mlength = ntohl(mlength);
-		if (mlength >= BUF_SIZE-4) {
-			oclog(ws, LOG_ERR, "kkdcp: too long message (%d bytes)", (int)mlength);
+		if (mlength >= BUF_SIZE - 4) {
+			oclog(ws, LOG_ERR,
+			      "kkdcp: too long message (%" PRIu32 " bytes)",
+			      mlength);
 			reason = "kkdcp: error receiving from server";
 			goto fail;
 		}
 
-		ret = force_read_timeout(fd, buf+4, mlength, KKDCP_READ_TIMEOUT);
+		ret = force_read_timeout(fd, buf + 4, mlength,
+					 KKDCP_READ_TIMEOUT);
 		if (ret == -1) {
 			e = errno;
-			oclog(ws, LOG_ERR, "kkdcp: recv error: %s", strerror(e));
+			oclog(ws, LOG_ERR, "kkdcp: recv error: %s",
+			      strerror(e));
 			reason = "kkdcp: error receiving from server";
 			goto fail;
 		}
 		length = ret + 4;
 	}
 
-	oclog(ws, LOG_HTTP_DEBUG, "HTTP processing kkdcp reply: %u bytes", (unsigned)length);
+	oclog(ws, LOG_HTTP_DEBUG, "HTTP processing kkdcp reply: %u bytes",
+	      length);
 
 	cstp_cork(ws);
 	ret = cstp_printf(ws, "HTTP/1.%u 200 OK\r\n", http_ver);
@@ -247,23 +267,22 @@ int post_kkdcp_handler(worker_st *ws, unsigned http_ver)
 		goto fail;
 	}
 
-	ret =
-	    cstp_puts(ws, "Content-Type: application/kerberos\r\n");
+	ret = cstp_puts(ws, "Content-Type: application/kerberos\r\n");
 	if (ret < 0) {
 		goto fail;
 	}
 
 	ret = der_encode_inplace(buf, &length, BUF_SIZE, &e);
 	if (ret < 0) {
-		oclog(ws, LOG_ERR, "kkdcp: DER encoding error: %s", asn1_strerror(e));
+		oclog(ws, LOG_ERR, "kkdcp: DER encoding error: %s",
+		      asn1_strerror(e));
 		reason = "kkdcp: DER encoding error";
 		goto fail;
 	}
 
-	oclog(ws, LOG_HTTP_DEBUG, "HTTP sending kkdcp framed reply: %u bytes", (unsigned)length);
-	ret =
-	    cstp_printf(ws, "Content-Length: %u\r\n",
-		       (unsigned int)length);
+	oclog(ws, LOG_HTTP_DEBUG, "HTTP sending kkdcp framed reply: %u bytes",
+	      length);
+	ret = cstp_printf(ws, "Content-Length: %u\r\n", length);
 	if (ret < 0) {
 		goto fail;
 	}
@@ -295,13 +314,11 @@ int post_kkdcp_handler(worker_st *ws, unsigned http_ver)
 
 	ret = 0;
 	goto cleanup;
- fail:
-	(void)cstp_printf(ws,
-			 "HTTP/1.%u 502 %s\r\n\r\n",
-			 http_ver, reason);
+fail:
+	(void)cstp_printf(ws, "HTTP/1.%u 502 %s\r\n\r\n", http_ver, reason);
 	ret = -1;
 
- cleanup:
+cleanup:
 	talloc_free(buf);
 	if (fd != -1)
 		close(fd);
@@ -310,7 +327,7 @@ int post_kkdcp_handler(worker_st *ws, unsigned http_ver)
 
 #else
 
-int post_kkdcp_handler(worker_st *ws, unsigned http_ver)
+int post_kkdcp_handler(worker_st *ws, unsigned int http_ver)
 {
 	return -1;
 }
