@@ -28,16 +28,17 @@
 #include <worker.h>
 #include <worker-latency.h>
 
-
 ssize_t dtls_pull_latency(gnutls_transport_ptr_t ptr, void *data, size_t size)
 {
 	int err;
 	dtls_transport_ptr *p = ptr;
+
 	p->rx_time.tv_sec = 0;
 	p->rx_time.tv_nsec = 0;
 
 	if (p->msg) {
 		ssize_t need = p->msg->data.len;
+
 		if (need > size) {
 			need = size;
 		}
@@ -49,34 +50,34 @@ ssize_t dtls_pull_latency(gnutls_transport_ptr_t ptr, void *data, size_t size)
 	}
 
 	char controlbuf[1024];
-	struct cmsghdr * cmsg;
+	struct cmsghdr *cmsg;
 
 	struct iovec io = {
 		.iov_base = data,
 		.iov_len = size,
 	};
-	struct msghdr hdr = {
-		.msg_iov = &io,
-		.msg_iovlen = 1,
-		.msg_control = controlbuf,
-		.msg_controllen = sizeof(controlbuf)
-	};
+	struct msghdr hdr = { .msg_iov = &io,
+			      .msg_iovlen = 1,
+			      .msg_control = controlbuf,
+			      .msg_controllen = sizeof(controlbuf) };
 	err = recvmsg(p->fd, &hdr, 0);
 	if (err >= 0) {
-		for (cmsg = CMSG_FIRSTHDR(&hdr); cmsg != NULL; cmsg = CMSG_NXTHDR(&hdr, cmsg)) {
+		for (cmsg = CMSG_FIRSTHDR(&hdr); cmsg != NULL;
+		     cmsg = CMSG_NXTHDR(&hdr, cmsg)) {
 			struct scm_timestamping *tss = NULL;
-			if (cmsg->cmsg_level != SOL_SOCKET || cmsg->cmsg_type != SCM_TIMESTAMPING) {
+
+			if (cmsg->cmsg_level != SOL_SOCKET ||
+			    cmsg->cmsg_type != SCM_TIMESTAMPING) {
 				continue;
 			}
-			tss = (struct scm_timestamping *) CMSG_DATA(cmsg);
+			tss = (struct scm_timestamping *)CMSG_DATA(cmsg);
 			p->rx_time = tss->ts[0];
 		}
 	}
 	return err;
 }
 
-
-void send_latency_stats_delta_to_main(worker_st * ws, time_t now)
+void send_latency_stats_delta_to_main(worker_st *ws, time_t now)
 {
 	LatencyStatsDelta msg = LATENCY_STATS_DELTA__INIT;
 
@@ -93,42 +94,49 @@ void send_latency_stats_delta_to_main(worker_st * ws, time_t now)
 	ws->latency.sample_set_count = 0;
 
 	send_msg_to_main(ws, CMD_LATENCY_STATS_DELTA, &msg,
-			 (pack_size_func) latency_stats_delta__get_packed_size,
-			 (pack_func) latency_stats_delta__pack);
+			 (pack_size_func)latency_stats_delta__get_packed_size,
+			 (pack_func)latency_stats_delta__pack);
 
 	ws->latency.last_stats_msg = now;
 }
 
-static int greater_than(const void * a, const void * b)
+static int greater_than(const void *a, const void *b)
 {
-    const unsigned long lhs = *(const unsigned long*)a;
-    const unsigned long rhs = *(const unsigned long*)b;
-    return rhs - lhs;
+	const unsigned long lhs = *(const unsigned long *)a;
+	const unsigned long rhs = *(const unsigned long *)b;
+
+	return rhs - lhs;
 }
 
-void capture_latency_sample(struct worker_st* ws, struct timespec *processing_start_time)
+void capture_latency_sample(struct worker_st *ws,
+			    struct timespec *processing_start_time)
 {
 	struct timespec now;
+
 	gettime_realtime(&now);
-	unsigned long sample = (unsigned long)timespec_sub_us(&now, processing_start_time);
+	unsigned long sample =
+		(unsigned long)timespec_sub_us(&now, processing_start_time);
+
 	if (ws->latency.next_sample == LATENCY_SAMPLE_SIZE) {
 		unsigned long median;
 		uint64_t total = 0;
+
 		long double sum_of_squares = 0;
 		uint64_t mean = 0;
 		uint64_t rms = 0;
 		int i;
 
 		ws->latency.next_sample = 0;
-		qsort(ws->latency.samples, LATENCY_SAMPLE_SIZE, sizeof(ws->latency.samples[0]), greater_than);
+		qsort(ws->latency.samples, LATENCY_SAMPLE_SIZE,
+		      sizeof(ws->latency.samples[0]), greater_than);
 		median = ws->latency.samples[LATENCY_SAMPLE_SIZE - 1];
 
-		for (i = 0; i < LATENCY_SAMPLE_SIZE; i ++) {
+		for (i = 0; i < LATENCY_SAMPLE_SIZE; i++) {
 			total += ws->latency.samples[i];
 		}
 
 		mean = total / LATENCY_SAMPLE_SIZE;
-		for (i = 0; i < LATENCY_SAMPLE_SIZE; i ++) {
+		for (i = 0; i < LATENCY_SAMPLE_SIZE; i++) {
 			long double delta = (long double)ws->latency.samples[i];
 			delta -= mean;
 			sum_of_squares += delta * delta;
@@ -138,8 +146,7 @@ void capture_latency_sample(struct worker_st* ws, struct timespec *processing_st
 
 		(ws->latency.median_total) += median;
 		(ws->latency.rms_total) += rms;
-		(ws->latency.sample_set_count) ++;
-    }
-    ws->latency.samples[(ws->latency.next_sample)++] = sample;
-
+		(ws->latency.sample_set_count)++;
+	}
+	ws->latency.samples[(ws->latency.next_sample)++] = sample;
 }
