@@ -76,11 +76,7 @@ enum {
 	HEADER_AUTHORIZATION
 };
 
-enum {
-	HTTP_HEADER_INIT = 0,
-	HTTP_HEADER_RECV,
-	HTTP_HEADER_VALUE_RECV
-};
+enum { HTTP_HEADER_INIT = 0, HTTP_HEADER_RECV, HTTP_HEADER_VALUE_RECV };
 
 enum {
 	S_AUTH_INACTIVE = 0,
@@ -100,30 +96,34 @@ enum {
 	AGENT_SVC_IPPHONE
 };
 
-typedef int (*decompress_fn)(void* dst, int maxDstSize, const void* src, int src_size);
-typedef int (*compress_fn)(void* dst, int dst_size, const void* src, int src_size);
+typedef int (*decompress_fn)(void *dst, int maxDstSize, const void *src,
+			     int src_size);
+typedef int (*compress_fn)(void *dst, int dst_size, const void *src,
+			   int src_size);
 
 typedef struct compression_method_st {
 	comp_type_t id;
 	const char *name;
 	decompress_fn decompress;
 	compress_fn compress;
-	unsigned server_prio; /* the highest the more we want to negotiate that */
+	unsigned int
+		server_prio; /* the highest the more we want to negotiate that */
 } compression_method_st;
 
 typedef struct dtls_ciphersuite_st {
-	const char* oc_name;
-	const char* gnutls_name; /* the gnutls priority string to set */
-	unsigned dtls12_mode;
-	unsigned server_prio; /* the highest the more we want to negotiate that */
-	unsigned gnutls_cipher;
-	unsigned gnutls_kx;
-	unsigned gnutls_mac;
-	unsigned gnutls_version;
+	const char *oc_name;
+	const char *gnutls_name; /* the gnutls priority string to set */
+	unsigned int dtls12_mode;
+	unsigned int
+		server_prio; /* the highest the more we want to negotiate that */
+	unsigned int gnutls_cipher;
+	unsigned int gnutls_kx;
+	unsigned int gnutls_mac;
+	unsigned int gnutls_version;
 } dtls_ciphersuite_st;
 
 #ifdef HAVE_GSSAPI
-# include <libtasn1.h>
+#include <libtasn1.h>
 /* main has initialized that for us */
 extern asn1_node _kkdcp_pkix1_asn;
 #endif
@@ -139,7 +139,7 @@ struct http_req_st {
 	char devplatform[MAX_AGENT_NAME]; /* Device-Platform */
 	char hostname[MAX_HOSTNAME_SIZE];
 	char user_agent[MAX_AGENT_NAME];
-	unsigned user_agent_type;
+	unsigned int user_agent_type;
 
 	unsigned int next_header;
 
@@ -154,18 +154,18 @@ struct http_req_st {
 	unsigned int body_length;
 
 	const dtls_ciphersuite_st *selected_ciphersuite;
-	unsigned use_psk; /* i.e., ignore selected_ciphersuite */
+	unsigned int use_psk; /* i.e., ignore selected_ciphersuite */
 
 	unsigned int headers_complete;
 	unsigned int message_complete;
-	unsigned link_mtu;
-	unsigned tunnel_mtu;
+	unsigned int link_mtu;
+	unsigned int tunnel_mtu;
 
-	unsigned no_ipv4;
-	unsigned no_ipv6;
+	unsigned int no_ipv4;
+	unsigned int no_ipv6;
 
 	char *authorization;
-	unsigned authorization_size;
+	unsigned int authorization_size;
 };
 
 typedef struct dtls_transport_ptr {
@@ -187,7 +187,8 @@ typedef struct dtls_st {
 
 /* Given a base MTU, this macro provides the DTLS plaintext data we can send;
  * the output value does not include the DTLS header */
-#define DATA_MTU(ws,mtu) (mtu-ws->dtls_crypto_overhead-ws->dtls_proto_overhead)
+#define DATA_MTU(ws, mtu) \
+	(mtu - ws->dtls_crypto_overhead - ws->dtls_proto_overhead)
 
 typedef struct worker_st {
 	gnutls_session_t session;
@@ -218,12 +219,12 @@ typedef struct worker_st {
 
 	unsigned int auth_state; /* S_AUTH */
 
-	struct sockaddr_un secmod_addr;	/* sec-mod unix address */
+	struct sockaddr_un secmod_addr; /* sec-mod unix address */
 	socklen_t secmod_addr_len;
 
-	struct sockaddr_storage our_addr;	/* our address */
+	struct sockaddr_storage our_addr; /* our address */
 	socklen_t our_addr_len;
-	struct sockaddr_storage remote_addr;	/* peer's address */
+	struct sockaddr_storage remote_addr; /* peer's address */
 	socklen_t remote_addr_len;
 	char our_ip_str[MAX_IP_STR];
 	char remote_ip_str[MAX_IP_STR];
@@ -259,8 +260,8 @@ typedef struct worker_st {
 	time_t last_stats_msg;
 
 	/* for mtu trials */
-	unsigned last_good_mtu;
-	unsigned last_bad_mtu;
+	unsigned int last_good_mtu;
+	unsigned int last_bad_mtu;
 
 	/* bandwidth stats */
 	bandwidth_st b_tx;
@@ -269,24 +270,26 @@ typedef struct worker_st {
 	/* ws->link_mtu: The MTU of the link of the connecting. The plaintext
 	 *  data we can send to the client (i.e., MTU of the tun device,
 	 *  can be accessed using the DATA_MTU() macro and this value. */
-	unsigned link_mtu;
-	unsigned adv_link_mtu; /* the MTU advertised on connection setup */
+	unsigned int link_mtu;
+	unsigned int adv_link_mtu; /* the MTU advertised on connection setup */
 
-	unsigned cstp_crypto_overhead; /* estimated overhead of DTLS ciphersuite + DTLS CSTP HEADER */
-	unsigned cstp_proto_overhead; /* UDP + IP header size */
+	unsigned int
+		cstp_crypto_overhead; /* estimated overhead of DTLS ciphersuite + DTLS CSTP HEADER */
+	unsigned int cstp_proto_overhead; /* UDP + IP header size */
 
-	unsigned dtls_crypto_overhead; /* estimated overhead of DTLS ciphersuite + DTLS CSTP HEADER */
-	unsigned dtls_proto_overhead; /* UDP + IP header size */
+	unsigned int
+		dtls_crypto_overhead; /* estimated overhead of DTLS ciphersuite + DTLS CSTP HEADER */
+	unsigned int dtls_proto_overhead; /* UDP + IP header size */
 
 	/* Indicates whether the new IPv6 headers will
 	 * be sent or the old */
-	unsigned full_ipv6;
+	unsigned int full_ipv6;
 
 	/* Buffer used by worker */
-	uint8_t buffer[16*1024];
+	uint8_t buffer[16 * 1024];
 	/* Buffer used for decompression */
-	uint8_t decomp[16*1024];
-	unsigned buffer_size;
+	uint8_t decomp[16 * 1024];
+	unsigned int buffer_size;
 
 	/* the following are set only if authentication is complete */
 
@@ -295,7 +298,7 @@ typedef struct worker_st {
 
 	char cert_username[MAX_USERNAME_SIZE];
 	char **cert_groups;
-	unsigned cert_groups_size;
+	unsigned int cert_groups_size;
 
 	char hostname[MAX_HOSTNAME_SIZE];
 	uint8_t cookie[SID_SIZE];
@@ -306,11 +309,11 @@ typedef struct worker_st {
 
 	uint8_t master_secret[TLS_MASTER_SIZE];
 	uint8_t session_id[GNUTLS_MAX_SESSION_ID];
-	unsigned cert_auth_ok;
+	unsigned int cert_auth_ok;
 	int tun_fd;
 
 	/* ban points to be sent on exit */
-	unsigned ban_points;
+	unsigned int ban_points;
 
 	/* tun device stats */
 	uint64_t tun_bytes_in;
@@ -318,7 +321,7 @@ typedef struct worker_st {
 
 	/* information on the tun device addresses and network */
 	struct vpn_st vinfo;
-	unsigned default_route;
+	unsigned int default_route;
 
 	void *main_pool; /* to be used only on deinitialization */
 
@@ -333,73 +336,72 @@ typedef struct worker_st {
 		uint32_t samples[LATENCY_SAMPLE_SIZE];
 	} latency;
 #endif
-    bool camouflage_check_passed;
+	bool camouflage_check_passed;
 } worker_st;
 
-void vpn_server(struct worker_st* ws);
+void vpn_server(struct worker_st *ws);
 
-int auth_cookie(worker_st *ws, void* cookie, size_t cookie_size);
+int auth_cookie(worker_st *ws, void *cookie, size_t cookie_size);
 int auth_user_deinit(worker_st *ws);
 
-int get_auth_handler(worker_st *server, unsigned http_ver);
-int post_auth_handler(worker_st *server, unsigned http_ver);
-int post_kkdcp_handler(worker_st *server, unsigned http_ver);
-int get_cert_handler(worker_st * ws, unsigned http_ver);
-int get_cert_der_handler(worker_st * ws, unsigned http_ver);
-int get_ca_handler(worker_st * ws, unsigned http_ver);
-int get_ca_der_handler(worker_st * ws, unsigned http_ver);
-int get_svc_handler(worker_st *ws, unsigned http_ver);
-int post_svc_handler(worker_st *ws, unsigned http_ver);
+int get_auth_handler(worker_st *server, unsigned int http_ver);
+int post_auth_handler(worker_st *server, unsigned int http_ver);
+int post_kkdcp_handler(worker_st *server, unsigned int http_ver);
+int get_cert_handler(worker_st *ws, unsigned int http_ver);
+int get_cert_der_handler(worker_st *ws, unsigned int http_ver);
+int get_ca_handler(worker_st *ws, unsigned int http_ver);
+int get_ca_der_handler(worker_st *ws, unsigned int http_ver);
+int get_svc_handler(worker_st *ws, unsigned int http_ver);
+int post_svc_handler(worker_st *ws, unsigned int http_ver);
 
-
-int response_404(worker_st *ws, unsigned http_ver);
-int response_401(worker_st *ws, unsigned http_ver, char* realm);
-int get_empty_handler(worker_st *server, unsigned http_ver);
+int response_404(worker_st *ws, unsigned int http_ver);
+int response_401(worker_st *ws, unsigned int http_ver, char *realm);
+int get_empty_handler(worker_st *server, unsigned int http_ver);
 #ifdef ANYCONNECT_CLIENT_COMPAT
-int get_config_handler(worker_st *ws, unsigned http_ver);
+int get_config_handler(worker_st *ws, unsigned int http_ver);
 #endif
-int get_string_handler(worker_st *ws, unsigned http_ver);
-int get_dl_handler(worker_st *ws, unsigned http_ver);
-int get_cert_names(worker_st * ws, const gnutls_datum_t * raw);
+int get_string_handler(worker_st *ws, unsigned int http_ver);
+int get_dl_handler(worker_st *ws, unsigned int http_ver);
+int get_cert_names(worker_st *ws, const gnutls_datum_t *raw);
 
 void set_resume_db_funcs(gnutls_session_t);
 
-typedef int (*url_handler_fn) (worker_st *, unsigned http_ver);
-int http_url_cb(llhttp_t * parser, const char *at, size_t length);
-int http_header_value_cb(llhttp_t * parser, const char *at, size_t length);
-int http_header_field_cb(llhttp_t * parser, const char *at, size_t length);
-int http_header_complete_cb(llhttp_t * parser);
-int http_message_complete_cb(llhttp_t * parser);
-int http_body_cb(llhttp_t * parser, const char *at, size_t length);
-void http_req_deinit(worker_st * ws);
-void http_req_reset(worker_st * ws);
-void http_req_init(worker_st * ws);
+typedef int (*url_handler_fn)(worker_st *, unsigned int http_ver);
+int http_url_cb(llhttp_t *parser, const char *at, size_t length);
+int http_header_value_cb(llhttp_t *parser, const char *at, size_t length);
+int http_header_field_cb(llhttp_t *parser, const char *at, size_t length);
+int http_header_complete_cb(llhttp_t *parser);
+int http_message_complete_cb(llhttp_t *parser);
+int http_body_cb(llhttp_t *parser, const char *at, size_t length);
+void http_req_deinit(worker_st *ws);
+void http_req_reset(worker_st *ws);
+void http_req_init(worker_st *ws);
 
-unsigned valid_hostname(const char *host);
+unsigned int valid_hostname(const char *host);
 
 url_handler_fn http_get_url_handler(const char *url);
-url_handler_fn http_post_url_handler(worker_st * ws, const char *url);
-url_handler_fn http_post_known_service_check(worker_st * ws, const char *url);
+url_handler_fn http_post_url_handler(worker_st *ws, const char *url);
+url_handler_fn http_post_known_service_check(worker_st *ws, const char *url);
 
-int complete_vpn_info(worker_st * ws,
-                    struct vpn_st* vinfo);
+int complete_vpn_info(worker_st *ws, struct vpn_st *vinfo);
 
 int send_tun_mtu(worker_st *ws, unsigned int mtu);
 int handle_commands_from_main(struct worker_st *ws);
 int disable_system_calls(struct worker_st *ws);
 void ocsigaltstack(struct worker_st *ws);
 
-void exit_worker(worker_st * ws);
-void exit_worker_reason(worker_st * ws, unsigned reason);
+void exit_worker(worker_st *ws);
+void exit_worker_reason(worker_st *ws, unsigned int reason);
 
-int ws_switch_auth_to(struct worker_st *ws, unsigned auth);
+int ws_switch_auth_to(struct worker_st *ws, unsigned int auth);
 int ws_switch_auth_to_next(struct worker_st *ws);
-void ws_add_score_to_ip(worker_st *ws, unsigned points, unsigned final, unsigned discon_reason);
+void ws_add_score_to_ip(worker_st *ws, unsigned int points, unsigned int final,
+			unsigned int discon_reason);
 
-int connect_to_secmod(worker_st * ws);
-inline static
-int send_msg_to_secmod(worker_st * ws, int sd, uint8_t cmd,
-		       const void *msg, pack_size_func get_size, pack_func pack)
+int connect_to_secmod(worker_st *ws);
+inline static int send_msg_to_secmod(worker_st *ws, int sd, uint8_t cmd,
+				     const void *msg, pack_size_func get_size,
+				     pack_func pack)
 {
 	oclog(ws, LOG_DEBUG, "sending message '%s' to secmod",
 	      cmd_request_to_str(cmd));
@@ -407,18 +409,18 @@ int send_msg_to_secmod(worker_st * ws, int sd, uint8_t cmd,
 	return send_msg(ws, sd, cmd, msg, get_size, pack);
 }
 
-int recv_auth_reply(worker_st * ws, int sd, char **txt, unsigned *pcounter);
-int get_cert_info(worker_st * ws);
-int parse_reply(worker_st * ws, char *body, unsigned body_length,
-		const char *field, unsigned field_size,
-		const char *xml_field, unsigned xml_field_size,
+int recv_auth_reply(worker_st *ws, int sd, char **txt, unsigned int *pcounter);
+int get_cert_info(worker_st *ws);
+int parse_reply(worker_st *ws, char *body, unsigned int body_length,
+		const char *field, unsigned int field_size,
+		const char *xml_field, unsigned int xml_field_size,
 		char **value);
 
-inline static
-int send_msg_to_main(worker_st *ws, uint8_t cmd,
-	    const void* msg, pack_size_func get_size, pack_func pack)
+inline static int send_msg_to_main(worker_st *ws, uint8_t cmd, const void *msg,
+				   pack_size_func get_size, pack_func pack)
 {
-	oclog(ws, LOG_DEBUG, "sending message '%s' to main", cmd_request_to_str(cmd));
+	oclog(ws, LOG_DEBUG, "sending message '%s' to main",
+	      cmd_request_to_str(cmd));
 	return send_msg(ws, ws->cmd_fd, cmd, msg, get_size, pack);
 }
 
@@ -426,7 +428,7 @@ int parse_proxy_proto_header(struct worker_st *ws, int fd);
 
 void cookie_authenticate_or_exit(worker_st *ws);
 
-int add_owasp_headers(worker_st * ws);
+int add_owasp_headers(worker_st *ws);
 
 /* after that time (secs) of inactivity in the UDP part, connection switches to
  * TCP (if activity occurs there).
