@@ -28,35 +28,41 @@
 #include "../src/config-ports.c"
 #include "../src/ipc.pb-c.h"
 
-int syslog_open = 0;
+int syslog_open;
 
-#define reset(x,y) { \
-	talloc_free(x); \
-	x = NULL; \
-	y = 0; }
+#define reset(x, y)             \
+	{                       \
+		talloc_free(x); \
+		x = NULL;       \
+		y = 0;          \
+	}
 
 void fw_port_st__init(FwPortSt *message)
 {
 }
 
-void check_vals(FwPortSt **fw_ports, size_t n_fw_ports) {
+void check_vals(FwPortSt **fw_ports, size_t n_fw_ports)
+{
 	if (n_fw_ports != 7) {
-		fprintf(stderr, "error in %d (detected %d)\n", __LINE__, (int)n_fw_ports);
+		fprintf(stderr, "error in %d (detected %d)\n", __LINE__,
+			(int)n_fw_ports);
 		exit(1);
 	}
 
-	if (fw_ports[0]->proto != PROTO_ICMP || fw_ports[1]->proto != PROTO_TCP || fw_ports[2]->proto != PROTO_UDP ||
-		fw_ports[3]->proto != PROTO_SCTP || fw_ports[4]->proto != PROTO_TCP ||
-		fw_ports[5]->proto != PROTO_UDP || fw_ports[6]->proto != PROTO_ICMPv6) {
-
+	if (fw_ports[0]->proto != PROTO_ICMP ||
+	    fw_ports[1]->proto != PROTO_TCP ||
+	    fw_ports[2]->proto != PROTO_UDP ||
+	    fw_ports[3]->proto != PROTO_SCTP ||
+	    fw_ports[4]->proto != PROTO_TCP ||
+	    fw_ports[5]->proto != PROTO_UDP ||
+	    fw_ports[6]->proto != PROTO_ICMPv6) {
 		fprintf(stderr, "error in %d\n", __LINE__);
 		exit(1);
 	}
 
 	if (fw_ports[1]->port != 88 || fw_ports[2]->port != 90 ||
-		fw_ports[3]->port != 70 || fw_ports[4]->port != 443 ||
-		fw_ports[5]->port != 80) {
-
+	    fw_ports[3]->port != 70 || fw_ports[4]->port != 443 ||
+	    fw_ports[5]->port != 80) {
 		fprintf(stderr, "error in %d\n", __LINE__);
 		exit(1);
 	}
@@ -70,7 +76,8 @@ int main(void)
 	size_t n_fw_ports = 0;
 	void *pool = talloc_new(NULL);
 
-	strcpy(p, "icmp(), tcp(88), udp(90), sctp(70), tcp(443), udp(80), icmpv6()");
+	strcpy(p,
+	       "icmp(), tcp(88), udp(90), sctp(70), tcp(443), udp(80), icmpv6()");
 
 	ret = cfg_parse_ports(pool, &fw_ports, &n_fw_ports, p);
 	if (ret < 0) {
@@ -82,7 +89,8 @@ int main(void)
 
 	/* check spacing tolerance */
 	reset(fw_ports, n_fw_ports);
-	strcpy(p, "icmp (  ), tcp	 (  88 ), udp  (  90  ), sctp  (  70   )   ,   tcp   (  443   )    ,  	 udp(80)  	, icmpv6 ( )   	");
+	strcpy(p,
+	       "icmp (  ), tcp	 (  88 ), udp  (  90  ), sctp  (  70   )   ,   tcp   (  443   )    ,	 udp(80)	, icmpv6 ( )	");
 
 	ret = cfg_parse_ports(pool, &fw_ports, &n_fw_ports, p);
 	if (ret < 0) {
@@ -111,7 +119,8 @@ int main(void)
 	}
 
 	reset(fw_ports, n_fw_ports);
-	strcpy(p, "!(icmp(), tcp(88), udp(90), sctp(70), tcp(443), udp(80), icmpv6())");
+	strcpy(p,
+	       "!(icmp(), tcp(88), udp(90), sctp(70), tcp(443), udp(80), icmpv6())");
 
 	ret = cfg_parse_ports(pool, &fw_ports, &n_fw_ports, p);
 	if (ret < 0) {
